#!/usr/bin/python

# Viscosity DNS Support Script
# http://www.viscosityvpn.com

import os, sys, re
from subprocess import *

# Update path for running instance to make sure we can find the programs
os.environ["PATH"] = '/bin:/sbin:/usr/sbin:/usr/bin'

# Get command line args
try:
    tun_dev, tun_mtu, link_mtu = sys.argv[1:4]
except:
	sys.exit(0)
	
# Restore old settings

networkInt = 'tap0'

def get_sc_store():
	return SCDynamicStoreCreate(None, "OpenVPN", handle_sc_event, None)

def handle_sc_event(store, changed_keys, info):
	for key in changed_keys:
          SC_HANDLERS[key](key=key, info=info)

# Remove DNS settings
try:

	# for Mac OS X Tiger and later, use supplemental match domains
	# see this thread for more information:
	# <http://lists.apple.com/archives/Macnetworkprog/2005/Jun/msg00011.html>
	from SystemConfiguration import *
	SC_IPV4_PATH, SC_DNS_PATH = ['/'.join((kSCDynamicStoreDomainState,
				   kSCCompNetwork, kSCCompService,
				   networkInt, ent))
				for ent in (kSCEntNetIPv4, kSCEntNetDNS)]
	store = get_sc_store()
	SCDynamicStoreRemoveValue(store, SC_DNS_PATH)
#	store.removeValueForKey_(SC_IPV4_PATH)
#	store.removeValueForKey_(SC_DNS_PATH)

	resolv_file_path = '/etc/resolv.conf'
	if os.path.exists('/var/run/resolv.conf'):
		resolv_file_path = '/var/run/resolv.conf'

	resolv_file = file(resolv_file_path, 'r+')
	resolv_lines = resolv_file.readlines()

	START_SKIP = '# begin %s OpenVPN tunnel modifications' % tun_dev
	END_SKIP = '# end %s OpenVPN tunnel modifications' % tun_dev

	in_skip = False

	resolv_file.seek(0)
	resolv_file.truncate()
	for line in resolv_lines:
		if in_skip:
			if re.match(END_SKIP, line):
				in_skip = False
			continue
		else:
			if re.match(START_SKIP, line):
				in_skip = True
				continue
		if line == '\n': continue
		line = re.sub(r'# \*#\* ', '', line)
		resolv_file.write(line)

	resolv_file.close()

except:
        import traceback
        file = open('/Library/Logs/Viscosity-DNSDOWN.log', 'w')
        file.write(traceback.format_exc())
        file.close()

cmd = 'dscacheutil -flushcache'
p = Popen(cmd, shell=True, stdin=PIPE, stdout=PIPE, stderr=STDOUT, close_fds=True)
p.stdout.read()
